@@ -23,6 +23,8 @@ class Folder(BaseModel):
 
 
 class File(BaseModel):
+    def __init__(self, data, state: ConnectionState):
+        self.id = data.get('id')
     id: str
     createdAt: str
     name: str
