@@ -330,3 +330,27 @@ class Note(AbstractNote):
         """
 
         return await self._state.add_note_to_clips(clip_id=clip_id, note_id=self.id)
+
+    async def create_renotes(            self, content: Optional[str],
+            cw: Optional[str] = None,
+            no_extract_mentions: bool = False,
+            no_extract_hashtags: bool = False,
+            no_extract_emojis: bool = False,
+            reply_id: Optional[str] = None,
+            channel_id: Optional[str] = None,
+            file_ids=None,
+            poll: Optional[Poll] = None
+            ) -> Note:
+        """
+        ノートをリノートします
+
+        Parameters
+        ----------
+        limit: int, default=10
+            謎
+        since_id: Optional[str], default=None
+            謎
+        until_id: Optional[str], default=None
+            謎
+        """
+        return await self._state.post_note()
